No return value, called for its side effects. A grouped data frame with class grouped_df
newobj is created on the server, unless the combination of tidy_expr and .add
yields a empty set of grouping columns, in which case a tibble will be created on the server.
Arguments
df.name
Character specifying a serverside data frame or tibble.
tidy_expr
List of variables or computations to group by.
.add
When FALSE, the default, group_by() will override existing groups. To add to the
existing groups, use .add = TRUE.
.drop
Drop groups formed by factor levels that don't appear in the data? The default is
TRUE except when .data has been previously grouped with .drop = FALSE.
newobj
Character specifying name for new server-side data frame.